-- Copyright 2009 FriendFeed
--
-- Licensed under the Apache License, Version 2.0 (the "License"); you may
-- not use this file except in compliance with the License. You may obtain
-- a copy of the License at
--
--     http://www.apache.org/licenses/LICENSE-2.0
--
-- Unless required by applicable law or agreed to in writing, software
-- distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-- WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-- License for the specific language governing permissions and limitations
-- under the License.

-- To create the database:
--   CREATE DATABASE blog;
--   CREATE USER blog WITH PASSWORD 'blog';
--   GRANT ALL ON DATABASE blog TO blog;
--
-- To reload the tables:
--   psql -U blog -d blog < schema.sql

DROP TABLE IF EXISTS lecturer;
CREATE TABLE lecturer (
    id SERIAL PRIMARY KEY,
    email VARCHAR(100) NOT NULL UNIQUE,
    name VARCHAR(100) NOT NULL,
    hashed_password VARCHAR(100) NOT NULL,
    role VARCHAR(100) NOT NULL
);

DROP TABLE IF EXISTS lectures;
CREATE TABLE lectures (   
    id SERIAL PRIMARY KEY,
    lecturer_id INT NOT NULL REFERENCES lecturer(id),
    -- start additional information
    module_number VARCHAR(255),
    semester VARCHAR(255),
    lecture_id VARCHAR(255),
    -- start fit platform columns
    -- start event
    identifier VARCHAR(255),
    workshop_status VARCHAR(255),
    title VARCHAR(255),
    type VARCHAR(255),
    facilities TEXT[],
    contact_person VARCHAR(255),
    description TEXT,
    description_for_certificate TEXT,
    -- start features
    skill VARCHAR(255),
    achievement_scores TEXT,
    deny_download_of_certificates BOOLEAN,
    certificate_blocks TEXT[],
    language VARCHAR(255),
    data_privacy_of_speakers_allowed BOOLEAN,
    speakers TEXT[],
    target_audiences TEXT[],
    -- start log-in settings
    no_registration_required BOOLEAN,
    registration_via_waiting_list BOOLEAN,
    registration_after_start_allowed BOOLEAN,
    registration_open_for_external BOOLEAN,
    min_seats INTEGER,
    max_seats INTEGER,
    registration_start_date DATE,
    registration_end_date DATE,
    cancellation_end_date DATE,
    -- start email settings
    reminder_mail_date DATE,
    text_for_registration_mail TEXT,
    text_for_reminder_mail TEXT,
    mail_footer TEXT,
    notify_waiting_list BOOLEAN,
    -- start dates
    start_date DATE,
    start_time TIME,
    end_date DATE,
    end_time TIME,
    -- start locations
    location_id TEXT,
    location_other TEXT,
    -- start else
    created_at TIMESTAMP NOT NULL,
    updated_at TIMESTAMP NOT NULL
);

DROP TABLE IF EXISTS neue_tabelle;
CREATE TABLE neue_tabelle (
    id SERIAL PRIMARY KEY,
    titel VARCHAR(100) NOT NULL,
    presenter VARCHAR(100) NOT NULL,
    datum DATE NOT NULL
);


CREATE INDEX ON lectures (created_at);
