import React, { useEffect, useState } from 'react';
import 'bootstrap/dist/css/bootstrap.min.css';
import { useNavigate } from "react-router-dom";

const CoursesPage = () => {
  const [courses, setCourses] = useState([]);
  const navigate = useNavigate();

  // Function to get a specific cookie value
  function getCookie(name) {
    const value = `; ${document.cookie}`;
    const parts = value.split(`; ${name}=`);
    if (parts.length === 2) return parts.pop().split(';').shift();
    return null;
  }

  // Function to fetch courses from the backend
  const fetchCourses = async () => {
    try {
      const response = await fetch('/backend/courses', {
        method: 'GET',
        credentials: 'include',
      });
      if (!response.ok) {
        const errorText = await response.text();
        throw new Error(`Network response was not ok: ${errorText}`);
      }
      const data = await response.json();
      const parsedCourses = JSON.parse(data.courses);
      console.log('Content of data.parsedCourses:', parsedCourses);
      setCourses(parsedCourses);
    } catch (error) {
      console.error('There was a problem with the fetch operation:', error);
    }
  };

  // Function to check if the user is authorized
  const CheckAuth = async () => {
    const xsrfToken = getCookie('_xsrf');
    const check = 'admin';
    try {
      const response = await fetch('/backend/check-auth', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
          'X-XSRFToken': xsrfToken,
        },
        body: JSON.stringify(check),
      });

      const result = await response.json();
      console.log(result.auth);
      if (response.ok && result.auth) {
        console.log('Authorized');
      } else {
        navigate('/unauth');
      }
    } catch (error) {
      console.error('Error setting XSRF token:', error);
    }
  };

  // useEffect hook to fetch courses and check authorization when the component mounts
  useEffect(() => {
    CheckAuth();
    fetchCourses();
  }, []);

  return (
    <div className="container mt-4">
      <h1 className="mb-4">Current Courses in FIT</h1>
      <div className="list-group">
        {courses.map(course => (
          <div key={course.identifier} className="list-group-item">
            <h2>{course.title}</h2>
            <p><strong>Status:</strong> {course.workshopStatus}</p>
            <p><strong>Contact:</strong> <a href={`mailto:${course.contactPerson}`}>{course.contactPerson}</a></p>
            <div dangerouslySetInnerHTML={{ __html: course.description }}></div>
            {course.dates && course.dates.map((date, index) => (
              <div key={index}>
                <p><strong>Start Date:</strong> {date.startDate}</p>
                <p><strong>End Date:</strong> {date.endDate}</p>
              </div>
            ))}
          </div>
        ))}
      </div>
    </div>
  );
};

export default CoursesPage;
