import React, { useEffect, useState } from 'react';
import { Link, useNavigate } from 'react-router-dom';
import 'bootstrap/dist/css/bootstrap.min.css';

const Login = () => {
  const navigate = useNavigate();

  // State to hold email, password, and error messages
  const [email, setEmail] = useState("");
  const [password, setPassword] = useState("");
  const [error, setError] = useState(null);

  // Function to get a specific cookie value
  function getCookie(name) {
    const value = `; ${document.cookie}`;
    const parts = value.split(`; ${name}=`);
    if (parts.length === 2) return parts.pop().split(';').shift();
    return null;
  }

  // useEffect hook to fetch XSRF token when the component mounts
  useEffect(() => {
    const fetchXsrfToken = async () => {
      try {
        const response = await fetch('/backend/set-xsrf-token', {
          method: 'GET',
          credentials: 'include', // important to include cookies
        });

        if (!response.ok) {
          throw new Error('Failed to set XSRF token');
        }

        console.log('XSRF token set');
      } catch (error) {
        console.error('Error setting XSRF token:', error);
      }
    };

    fetchXsrfToken();
  }, []);

  // Function to handle login
  const handleLogin = async () => {
    const xsrfToken = getCookie('_xsrf');
    console.log(password, email);
    const response = await fetch('/backend/lecturer/login-handler', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
        'X-XSRFToken': xsrfToken,
      },
      credentials: 'include',
      body: JSON.stringify({ email, password }),
    });
    const result = await response.json();
    console.log(result);
    if (response.ok && result.success) {
      navigate('/form');
    } else {
      setError(result.message || "Login failed. Please check your credentials.");
    }
  };

  return (
    <div className="container mt-5">
      <h2>Login</h2>
      <form>
        <div className="mb-3">
          <label htmlFor="email" className="form-label">Email</label>
          <input
            type="text"
            className="form-control"
            id="email"
            value={email}
            onChange={(e) => setEmail(e.target.value)}
          />
        </div>
        <div className="mb-3">
          <label htmlFor="password" className="form-label">Password</label>
          <input
            type="password"
            className="form-control"
            id="password"
            value={password}
            onChange={(e) => setPassword(e.target.value)}
          />
        </div>
        <button type="button" className="btn btn-primary" onClick={handleLogin}>Login</button>
      </form>
      <p>Don't have an account? <Link to="/register">Register here</Link></p>
      {error && <div className="alert alert-danger mt-3">{error}</div>}
    </div>
  );
};

export default Login;
